<?php
/*
 * ARTURO: Codigo para la Creacion de un custom type para ABM de paypals
 * 1 Creación del usuario supervisor
 * 2 Si tiene privilegio 'ver_paypals' registra un new_post_type
 * 2.1 Agrega los meta boxes para el Custom Post Type Paypal *Por paises
 * 2.2 Genera el contenido que hay que mostrar dentro del meta box *Por paises
 * 2.3 Graba los campos del formulario del meta box *Por paises
 * 2.4 Personalizar columnas
 * 3 Agregar un listener para paypal checkout
 * 4 Crear un shortcode 'paypals' 
 * 5 Crear un template para el tipo de pagina paypals (Si no existe)
 * 6 Crear una page 'listapaypals' (Si no existe)
 */

/**
 * 1.- Creación del usuario supervision por una sola vez
 */

function usuariopaypal(){
	if(get_role("shop_supervisor") !== null){
		add_role( 'shop_supervisor', 'Shop Supervisor', get_role( 'shop_manager' )->capabilities);
		$admin = get_role('administrator');
		$admin->add_cap('ver_paypals');
	}
	//$despa = get_role('shop_manager');
	//$despa->add_cap('ver_paypals');

	if(!username_exists('supervision'))
	{
		$user_id = wp_create_user( 'supervision', 'Supervision.2021*', 'supervision@windowsandoffice.com' );
		$user = new WP_User( $user_id );
		$user->set_role( 'shop_supervisor' );
		
		//$super = get_role('shop_supervisor');
		//$super->add_cap('ver_paypals');
	}
	if(!username_exists('despacho'))
	{
		$user_id = wp_create_user( 'despacho', 'Despacho.2021*', 'despacho@windowsandoffice.com' );
		$user = new WP_User( $user_id );
		$user->set_role( 'shop_manager' );

		//$despa = get_role('shop_supervisor');
		//$despa->add_cap('ver_paypals');
	}
	$user = wp_get_current_user();
	$role = $user->roles;

}//fin de funcion usuariopaypal

add_action( 'admin_init', 'usuariopaypal' );

	/**
	 * 2.- Si tiene privilegio 'ver_paypals' registra un new_post_type
	 */

add_action('init', 'register_new_post_type');

function register_new_post_type()
{
	if(current_user_can('ver_paypals')){
		$args = array(
			'public' => true,
			'labels' => array(
			'name' => 'Paypals',
			'singular_name' => 'Paypal',
			'all_items' => 'Todos los Paypals',
			'add_new' => 'Agregar nuevo Paypal',
			'add_new_item' => 'Agregar nuevo Paypal',
			'edit_item' => 'Editar Paypal',
			'new_item' => 'Nuevo Paypal',
			'view_item' => 'Ver Paypal',
			'search_items' => 'Buscar Paypals',
			'not_found' => 'No se han encontrado Paypals',
			'not_found_in_trash' => 'No se han encontrado Paypals en la Papelera'
			),
		 'supports' => array( 'title' )
		);

		register_post_type('Paypals', $args);
	}//fin de si es admin
}//fin de funcion
	
/**
 * 2.1.-Agrega los meta boxes para el Custom Post Type Paypal
 * https://developer.wordpress.org/reference/functions/add_meta_box/
 */


function kfp_paypal_register_meta_boxes()
{
    add_meta_box('Paypal-Parameters', 'Parametros', 'kfp_paypal_output_meta_box', 'Paypals', 'normal', 'high');
}

/**
 * 2.2 Genera el contenido que hay que mostrar dentro del meta box
 * @param WP_Post $post WordPress Post object
 */


function kfp_paypal_output_meta_box($post)
{
    // Los campos se graban en la base de datos con un subrayado bajo como prefijo
    // WP indica así por defecto que son campos metas
    $liveAPIUsername = get_post_meta($post->ID, '_liveAPIUsername', true);
    $liveAPIPassword = get_post_meta($post->ID, '_liveAPIPassword', true);
    $liveAPISignature = get_post_meta($post->ID, '_liveAPISignature', true);
    $forsites = get_post_meta($post->ID, '_forsites', true);
    wp_nonce_field( 'graba_paypal', 'paypal_nonce' );
    echo('<label for="liveAPIUsername">' . __('Live API Username: ', 'pluginwao') . '</label>');
    echo('<input type="text" name="liveAPIUsername" id="liveAPIUsername" style="width:300px;margin-left:10px;" value="' . esc_attr($liveAPIUsername) . '"><br><br>');
    
    echo('<label for="liveAPIPassword">' . __('Live API Password: ', 'pluginwao') . '</label>');
    echo('<input type="text" name="liveAPIPassword" id="liveAPIPassword" style="width:300px;margin-left:16px;" value="' . esc_attr($liveAPIPassword) . '"><br><br>');
    
    echo('<label for="liveAPISignature">' . __('Live API Signature: ', 'pluginwao') . '</label>');
    echo('<input type="text" name="liveAPISignature" id="liveAPISignature" style="width:300px;margin-left:18px;" value="' . esc_attr($liveAPISignature) . '"><br><br>');
	

	$sites = get_sites();
    echo('<label for="forsites">' . __('Sites: ', 'pluginwao') . '</label>');
    echo '<select style="margin-left:95px;width:300px;" name="forsites[]" id="forsites" multiple size="12">';
	foreach ( $sites as $site ) {
		switch_to_blog( $site->blog_id );
		//$opt = get_option( '_invoices_options' );
		if($forsites<>FALSE){
			$sel=in_array($site->blog_id,$forsites)?"selected":"";
		}//if forsites false END
		echo "<option value='".$site->blog_id."' ".$sel." >".$site->blogname."</option>";
	}//fin de foreach
	echo "</select>";	
	restore_current_blog();
}
add_action('add_meta_boxes', 'kfp_paypal_register_meta_boxes');

/**
 * 2.3 Graba los campos del formulario del meta box
 * @param int $post_id Post ID
 * @return bool|int
 */

function kfp_paypal_save_meta_boxes($post_id)
{
    // Comprueba que el nonce es correcto para evitar ataques CSRF
    if ( !isset($_POST['paypal_nonce']) || ! wp_verify_nonce( $_POST['paypal_nonce'], 'graba_paypal') ) {
        return $post_id;
    }

    // Comprueba que el tipo de post es receta
    if ('paypals' != $_POST['post_type']) {
        return $post_id;
    }

    // Comprueba que el usuario actual tiene permiso para editar esto
    if (!current_user_can('edit_post', $post_id)) {
        return $post_id;
    }

    // Ahora puedes grabar los datos con tranquilidad
    // Observa que cuando vienen del formulario los campos meta no vienen con el prefijo subrayado bajo pero cuando los grabas en el post hay que poner el prefijo, igual que cuando los leías del post
    $liveAPIUsername = sanitize_text_field($_POST['liveAPIUsername']);
    update_post_meta($post_id, '_liveAPIUsername', $liveAPIUsername);
    $liveAPIPassword = sanitize_text_field($_POST['liveAPIPassword']);
    update_post_meta($post_id, '_liveAPIPassword', $liveAPIPassword);
    $liveAPISignature = sanitize_text_field($_POST['liveAPISignature']);
    update_post_meta($post_id, '_liveAPISignature', $liveAPISignature);
    $forsites = $_POST['forsites'];
    update_post_meta($post_id, '_forsites', $forsites);
    return true;
}

add_action('save_post', 'kfp_paypal_save_meta_boxes');

/**
 * 2.4 Personalizar columnas
 */
	function personalizar_columnas1( $columns ) 
	{
		$columns1 = array(
		  'username' => __( 'User Name', 'paypals' ),
		  'countries' => __( 'Countries', 'paypals' )
		);
		$columns=array_merge($columns, $columns1);
	  return $columns;
	}//function personalizar columna END

	add_filter( 'manage_paypals_posts_columns', 'personalizar_columnas1');

	function admin_style1() {
	echo "<style>.column-username {width:300px;} .column-primary {width:300px;}</style>";
	}
	add_action('admin_enqueue_scripts', 'admin_style1');


/**
 * 2.5 Personalizar contenidos
 */

	function personalizar_contenidos1( $column, $post_id ) 
	{
	  $info = get_post_meta($post_id);
	  $info1 = get_post($post_id);
	  switch ($column)
	  {
		case 'username':
			echo $info['_liveAPIUsername'][0];
		  break;
		case 'countries':
			$blog_id = get_current_blog_id();
			$sites=get_post_meta($post_id,'_forsites');
			$salida="";
			if(!empty($sites[0])){
				foreach($sites[0] as $site){
					switch_to_blog( $site);
					$optblogname = get_option( 'blogname' );
					$salida.="<span style='background-color:azure;border:solid gray 1px;border-radius:3px;font-size:10px;margin-left:3px;padding:0px 3px 0px 3px'>".$optblogname."</span>";
					restore_current_blog();
				}
			}//if sites false END
			echo $salida;
		  break;
	  }
	}//function personalizar contenidos END

	add_action( 'manage_paypals_posts_custom_column', 'personalizar_contenidos1', 10, 2);

/*3.- Agregar un listener para paypal checkout*/

function mi_script() 
{
	$opt = get_option( '_invoices_options' );
	$subd=$opt{'subdirectorio'};
    echo '
    <script type="text/javascript">
	//*woocommerce_ppec_paypal_api_username* es el nombre y id del input que al hacer clic abrirá una ventana emergente vinculada desde donde se seleccionará el paypal.
	var el = document.getElementById("woocommerce_ppec_paypal_api_username");
	el.addEventListener("click", (event) => {
	    //listapaypals es el permalink de una pagina que se debe crear y añadir el shortcode [paypals]
	    //La pagina debe ser configurada con un template de ancho completo, si no existiere, crear uno en wp-content/themes/nombredeltema/page-templates/nombretemplate.php
	    window.open("'.$subd.'/listapaypals", "Seleccionar paypal", "toolbar=0,scrollbars=0,location=0,statusbar=0,menubar=0,resizable=1,width=700,height=400,left = 890,top = 500");
	    }
	);
    </script>';
}

add_action( 'admin_footer', 'mi_script' );

/*4.- Crear un shortcode 'paypals'*/

function funcion_paypals() {
if(current_user_can('ver_paypals')){
	//Obtenemos el total de paypals
	global $wpdb;
	$total=$wpdb->get_var("SELECT COUNT(ID) FROM {$wpdb->prefix}posts WHERE post_status='publish' AND post_type='paypals'");
	//Deducimos el numero de pagina
/*	$o=$_SERVER["REQUEST_URI"];
	$off=explode("/page/",$o);
	$page=str_replace("/","",$off[1]);
	$page=$page<>""?$page:1;
	//Establecemos el número de posts por pagina
	$ppp=40;
	//Calculamos el total de paginas que se necesitaran
	$totalpages=ceil($total/$ppp);
	//Calculamos el offset
	$offset=($page*$ppp)-$ppp+1;
*/
    $args = array(
	'posts_per_page'   => $total,
	'offset'           => 0,
	'category'         => '',
	'orderby'          => 'post_title',
	'order'            => 'ASC',
	'post_type'        => 'paypals',
	'post_status'      => 'publish',
	'suppress_filters' => true ); 
    $paypls = get_posts($args);

	$tabla.="<h3 style='text-align:center;'>SELECCIONE UN PAYPAL.</h3>";
    //$tabla.="<table class='wp-list-table widefat fixed striped table-view-list posts'>";
	$tabla.="<table class='wp-list-table striped' align='center'>";
    //$tabla.="<tr><td>NOMBRE PAYPAL</td><td>USERNAME</td><td>PASSWORD</td><td>SIGNATURE</td></tr>";
    //$tabla.="<tr><td align='center'>NOMBRE PAYPAL</td></tr>";
	$tabla.="<tr><td  align='right' width='10%'>NR.</td><td align='center' width='80%'>NOMBRE PAYPAL</td></tr>";
    $scripts="";
	$i=1;
    foreach ($paypls as $paypl){
		$id =$paypl->ID;
		$blog_id = get_current_blog_id();
		$sites=get_post_meta($id,'_forsites');
		if (!empty($sites[0])){
			if(in_array($blog_id,$sites[0])){
				
				$tabla.="<tr>";
				$tabla.="<tr><td align='right'><input style='width:30px;' readonly value='".$i++."'></td>";
				$tabla.="<td align='center'><input id='in_".$id."' name='in_".$id."' readonly value='".$paypl->post_title."'></td>";

				$liveAPIUsername=get_post_meta($id,'_liveAPIUsername');
				$liveAPIPassword=get_post_meta($id,'_liveAPIPassword');
				$liveAPISignature=get_post_meta($id,'_liveAPISignature');

				$APIUsername=$liveAPIUsername[0];
				$APIPassword=$liveAPIPassword[0];
				$APISignature=$liveAPISignature[0];
				//$tabla.="<td>".$APIUsername."</td>";$tabla.="<td>".$APIPassword."</td>";$tabla.="<td>".$APISignature."</td>";
				$tabla.="</tr>";
				$scripts.="var el = document.getElementById('in_".$id."');
					el.addEventListener('click', (event) => {
					window.opener.document.getElementById('woocommerce_ppec_paypal_api_username').value='".$APIUsername."';//TextBox1 is in parent page
					window.opener.document.getElementById('woocommerce_ppec_paypal_api_password').value='".$APIPassword."';//TextBox1 is in parent page
					window.opener.document.getElementById('woocommerce_ppec_paypal_api_signature').value='".$APISignature."';//TextBox1 is in parent page
					window.close();
					},true
					);";

			}//if in array blog id END
		}//if isset sites END
    }//foreach paypls END
    $tabla.="</table>";
    $url="https://".$_SERVER['SERVER_NAME']."/wp-admin/edit.php?post_type=paypals";
    //$tabla.="<br><p style='text-align:right'><a href='".$url."'>AÑADIR/MODIFICAR/BORRAR PAYPALS</a></p>";

	// solo seguimos con el resto si tenemos más de una página
/*	if ( $totalpages > 1 )  {
		 // obtenemos la página actual
		 if ( !$current_page = get_query_var('paged') )
			  $current_page = 1;
		 // la estructura de “format” depende de si usamos enlaces permanentes "humanos"
		 $format = empty( get_option('permalink_structure') ) ? '&page=%#%' : 'page/%#%/';
		 echo paginate_links(array(
			  'base' => get_pagenum_link(1) . '%_%',
			  'format' => $format,
			  'current' => $current_page,
			  'prev_next' => True,
			  'prev_text' => __('&laquo; Back'),
			  'next_text' => __('Next &raquo;'),
			  'total' => $totalpages,
			  'mid_size' => 4,
			  'type' => 'plain'
		 ));
	}
*/
    $tabla.= "<script type='text/javascript'>";
    $tabla.=$scripts;
    $tabla.= "</script>";
    return $tabla;
    }else{
    return '<meta http-equiv="refresh" content="2;URL=/shop">';
    }
}
add_shortcode('paypals','funcion_paypals');

/*5.- Crear un template para el tipo de pagina paypals (Si no existe)*/

function paypal_page_template(){
	$file1=get_stylesheet_directory()."/paypals_template.php";
	//unlink($file1);
	if(!file_exists($file1)){
	//echo "ruta : ".$file1;
		//$texto = "UN TEXTO X";
		$texto = '<'.'?'.'php'.PHP_EOL;
		$texto .= '/**'.PHP_EOL;
		$texto .= ' * Temp'.'late Name: Paypals Template 1'.PHP_EOL;
		$texto .= ' *'.PHP_EOL;
		$texto .= ' * Displays the Paypals Table page template.'.PHP_EOL;
		$texto .= ' *'.PHP_EOL;
		$texto .= ' */'.PHP_EOL;
		$texto .= '?>'.PHP_EOL;
		$texto .= '<html>'.PHP_EOL;
		$texto .= '<head>'.PHP_EOL;
		$texto .= '<meta name="robots" content="noindex,nofollow">'.PHP_EOL;
		$texto .= '<link rel="stylesheet" href="'.site_url().'/wp-admin/load-styles.php?c=0&amp;dir=ltr&amp;load%5Bchunk_0%5D=dashicons,admin-bar,wp-pointer,buttons,media-views,common,forms,admin-menu,dashboard,list-tables,edit,revisions,media,themes,abo&amp;load%5Bchunk_1%5D=ut,nav-menus,widgets,site-icon,l10n,wp-auth-check,wp-components,wp-jquery-ui-dialog&amp;ver=5.8.2" type="text/css" media="all" />'.PHP_EOL;
		$texto .= '</head>'.PHP_EOL;
		$texto .= '<body>'.PHP_EOL;
		$texto .= '<div class="wrap">'.PHP_EOL;
		$texto .= '	<div id="primary" class="content-area">'.PHP_EOL;
		$texto .= '			<'.'?'.'php '.PHP_EOL;
		$texto .= '			the_content();'.PHP_EOL;
		$texto .= '			?'.'>'.PHP_EOL;
		$texto .= '	</div>'.PHP_EOL;
		$texto .= '</body>'.PHP_EOL;
		$texto .= '</html>'.PHP_EOL;

		$file1_p=fopen($file1,'w');
		fwrite($file1_p, $texto);
		fclose($file1_p);

	}
	
}//fin de funcion template
add_action( 'admin_init', 'paypal_page_template' );


/*6.- Crear una page 'listapaypals' (Si no existe)*/
function lista_paypals_page(){
//	global $wpdb;
//	$my_posts = $wpdb->get_row( 'SELECT ID FROM {$wpdb->prefix}posts WHERE post_title  = "listapaypals" AND post_status="publish"');
	$args = array(
		'post_type' =>	'page',
		'title'	=> 'listapaypals'
	);
	//	'status'	=> 'publish'
	$my_posts = get_posts( $args );
	if(empty($my_posts))
	{
		$parametros=array(
		'ID'=>'',
		'post_author'=>$user->ID,
		'post_content'=>'[paypals]',
		'post_title'=>'listapaypals',
		'post_name'=>'listapaypals',
		'post_status'=>'publish',
		'post_type'=>'page'
		);
		$post_id = wp_insert_post($parametros);
		add_post_meta($post_id, '_wp_page_template', 'paypals_template.php', true);
	}// Fin de empty
	
}

add_action( 'admin_init', 'lista_paypals_page' );

/*FIN DE: Codigo para la Creacion de un custom type para ABM de paypals*/

